==> hyades.source_1.3.0_20040422_2239.zip: org/eclipse/hyades/test/http/internal/junit/editor/HttpBehaviorForm.java <==
/*******************************************************************************
 * Copyright (c) 2003 Hyades project.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.hyades.test.http.internal.junit.editor;

import org.eclipse.hyades.test.common.internal.editor.BehaviorSection;
import org.eclipse.hyades.test.http.TestHttpPlugin;
import org.eclipse.hyades.test.java.internal.junit.editor.JUnitBehaviorForm;
import org.eclipse.hyades.test.ui.internal.editor.form.util.WidgetFactory;

/**
 * @author marcelop
 * @since 1.0.2
 */
public class HttpBehaviorForm
extends JUnitBehaviorForm
{
	/**
	 * Constructor for HttpBehaviorForm
	 * @param junitEditorExtension
	 * @param widgetFactory
	 */
	public HttpBehaviorForm(HttpEditorExtension httpEditorExtension, WidgetFactory widgetFactory)
	{
		super(httpEditorExtension, widgetFactory);
		setHeadingText(TestHttpPlugin.getString("EDT_GENERAL_INFO"));
	}
	
	/**
	 * @see org.eclipse.hyades.test.common.internal.editor.BehaviorForm#createBehaviorSection()
	 */
	protected BehaviorSection createBehaviorSection()
	{
		return new HttpBehaviorSection(this);
	}
	
	/**
	 * @see org.eclipse.hyades.test.common.internal.editor.TestCasesForm#registerHelp(int, java.lang.Object)
	 */
	protected void registerHelp(int flag, Object object)
	{
		switch(flag)
		{
			case HELP_NAMED_ELEMENT_CONTROL:
				break;
				
			case HELP_FORM_CONTROL:
				break;
				
			case HELP_SECTION_CONTROL:
				break;
		}
	}	
}

==> hyades.source_3.2.0_20041221_1637.zip: org/eclipse/hyades/test/http/internal/junit/editor/HttpBehaviorForm.java <==
/*******************************************************************************
 * Copyright (c) 2003, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.hyades.test.http.internal.junit.editor;

import org.eclipse.hyades.test.common.internal.editor.BehaviorSection;
import org.eclipse.hyades.test.http.TestHttpPlugin;
import org.eclipse.hyades.test.java.internal.junit.editor.JUnitBehaviorForm;
import org.eclipse.hyades.test.ui.editor.form.util.WidgetFactory;

/**
 * @author marcelop
 * @since 1.0.2
 */
public class HttpBehaviorForm
extends JUnitBehaviorForm
{
	/**
	 * Constructor for HttpBehaviorForm
	 * @param junitEditorExtension
	 * @param widgetFactory
	 */
	public HttpBehaviorForm(HttpEditorExtension httpEditorExtension, WidgetFactory widgetFactory)
	{
		super(httpEditorExtension, widgetFactory);
		setHeadingText(TestHttpPlugin.getString("EDT_GENERAL_INFO"));
	}
	
	/**
	 * @see org.eclipse.hyades.test.common.internal.editor.BehaviorForm#createBehaviorSection()
	 */
	protected BehaviorSection createBehaviorSection()
	{
		return new HttpBehaviorSection(this);
	}
	
	/**
	 * @see org.eclipse.hyades.test.common.internal.editor.TestCasesForm#registerHelp(int, java.lang.Object)
	 */
	protected void registerHelp(int flag, Object object)
	{
		switch(flag)
		{
			case HELP_NAMED_ELEMENT_CONTROL:
				break;
				
			case HELP_FORM_CONTROL:
				break;
				
			case HELP_SECTION_CONTROL:
				break;
		}
	}	
}
